"""
EMIL EMAIL CLIENT
WRITTEN BY ANDREAS PRLIC <andorsch@gmx.at> 
this document is protected by the GPL 
"""

import Globals
import OFS
from OFS import SimpleItem
import string
from Globals import DTMLFile



class Email(SimpleItem.SimpleItem):
    "an email message"

    meta_type = "Email"
    manage_options = (
	{'label': 'View',     'action': 'index_html'},	
	{'label': 'Reply',    'action': 'reply_mail'},
	)
    
    def __init__(self,id,title,size,uid) :
	"create a email message from a list of lines"

	self.id      = id
	self.title   = title
	# should display the correct size of the mail in zope, but does not work :-/
	self.size    = size
	
	# uid = unique id from email server for this message
	# it is used to keep distinguish read / unread messages from server	
	self.uid     = uid

	# at some point status should be displayed for every email
	self.possible_status = ['read', 'unread', 'replied', 'forwarded' , 'sent', 'queued']
	self.status  = 'unread'

	# the email data
	self.From    = None
	self.To      = None
	self.Subject = None
	self.Body    = ""
	self.Head    = ""
	self.Date    = None


    def from_server_list(self,message_lst):
    
	body = 0
	for line in message_lst :

	    if body :
		self.Body = self.Body + line + "\n"

	    else :
		if string.find(string.lower(line),'from: ') == 0 :
		    line = line[6:]
		    line = self.change_larger_smaller(line)	
		    self.From = line
		elif string.find(string.lower(line),'to: ') == 0:
		    line = line[4:]
		    line = self.change_larger_smaller(line)		  		    
		    self.To = line
		elif string.find(string.lower(line),'subject: ') == 0:
		    line = line[9:]
		    self.Subject = line
		elif string.find(string.lower(line),'date: ') == 0:
		    line = line[6:]
		    self.Date =line
		elif line == ''  :
		    body = 1
		    continue
		else :
		    self.Head = self.Head + line + "\n"
	self.title = "%s\n%s" % (self.From,self.Subject)

    index_html       = DTMLFile('dtml/email_index_html'      , globals())

    def set_values(self, title='',		   
		   uid=None,
		   status='unread',
		   size=0,
		   From='',
		   To='',
		   Subject='',
		   Body='',
		   Head='',
		   Date='') :
	" set values of an email from outside"
		   
	self.title   = title
	self.size    = size
	self.uid     = uid
	self.set_status(status)
	# the email data
	self.From    = From
	self.To      = To
	self.Subject = Subject
	self.Body    = Body
	self.Head    = Head
	self.Date    = Date

    def reply_mail(self) :
	" reply message "
	# format body to contain ">" reply symbol still missing

	# call the write mail dtml document. ( it is created from email folder )
	return self.write_mail_html(To=self.From)

    
    def change_larger_smaller(self,line) :
	" format < and > symbols to avoid confusin with html tag "
	line = string.replace(line, "<", "&lt;")
	line = string.replace(line, ">", "&gt;")
	return line


    def highlight_links(self,txt):
	" change appeareance of email, urls "
	ret = ""
	import re
	
	for line in string.split(txt,"\n") :
	    # change emails
	    pat = re.search("([a-zA-Z0-9\._-]*)@([a-zA-Z0-9\._-]*)",line)
	   
	    if  pat != None:
		user  = pat.group(1)
		server= pat.group(2)
		str = "%s@%s" % (user,server)
		#line = string.replace(line,str,'<a href="mailto:%s">%s</a>'% (str,str))
		line = string.replace(line,str,'<a href="write_mail_html?To=%s">%s</a>'\
				      % (str,str))
	    # change urls
	    pat2 = re.search("(http://[a-zA-Z0-9\._\-\/]*)",line)
	    if pat2 != None :
		url = pat2.group(1)
		line = string.replace(line,url,'<a href="%s">%s</a>' % (url,url))
	    ret = ret + line + "\n"

	return ret

    def set_status(self,status) :
	" change the status of an email" 
	if status in self.possible_status :
	    # only change if status = unread
	    
	    if self.status == 'unread' or self.status == 'queued' :
		self.status = status 
	else :
	    raise "unknown_email_status", "unkown status: %s" % status
	
	return ""
    
def manage_addEmail(self,id, title='',message_lst='', size='0 Kb', uid =None, REQUEST=None) :
    " add a email to Zope "

    self._setObject(id, Email(id,title,size,uid))
    
    if REQUEST is not None: return self.manage_main(self,REQUEST)




